@@ -10,13 +10,16 @@ import publication
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_apigatewayv2._jsii
+import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_rds._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-serverless-lamp", "1.2.1", __name__[0:-6], "cdk-serverless-lamp@1.2.1.jsii.tgz"
+    "cdk-serverless-lamp", "1.3.0", __name__[0:-6], "cdk-serverless-lamp@1.3.0.jsii.tgz"
 )
 
 __all__ = [
